@@ -560,7 +560,7 @@ static GxRgba no_data_color = { 1.0, 1.0, 1.0, 0.6 };
 
 static void set_color_from_style(cairo_t *c, GxIREdit *ir_edit, gint type, double alpha)
 {
-	GtkStyle *s = GTK_WIDGET(ir_edit)->style;
+	GtkStyle *s = gtk_widget_get_style(GTK_WIDGET(ir_edit));
 	GdkColor *clr;
 	switch (type) {
 	case COLOR_BG: clr = s->bg; break;
@@ -978,7 +978,8 @@ static gboolean ir_edit_expose(GtkWidget *widget, GdkEventExpose *event)
 	cairo_clip(c);
 	if (ir_edit->locked) {
 		gint width, height;
-		gdk_drawable_get_size(ir_edit->surface, &width, &height);
+		width = gdk_window_get_width(ir_edit->surface);
+		height = gdk_window_get_height(ir_edit->surface);
 		if (width !=  ir_edit->width && height != ir_edit->height) {
 			ir_edit_lock_surface(ir_edit, ir_edit->locked);
 		}
