@@ -268,9 +268,9 @@ void _gx_knob_expose(GtkWidget *widget, GdkRectangle *image_rect, gdouble knobst
 		cairo_destroy (cr);
 	}
 	else {
-		cairo_t *cr = gdk_cairo_create(GDK_DRAWABLE(widget->window));
+		cairo_t *cr = gdk_cairo_create(GDK_DRAWABLE(gtk_widget_get_window(widget)));
 		if (gtk_widget_has_focus(widget)) {
-			gtk_paint_focus(widget->style, widget->window, GTK_STATE_NORMAL, NULL, widget, NULL,
+			gtk_paint_focus(gtk_widget_get_style(widget), gtk_widget_get_window(widget), GTK_STATE_NORMAL, NULL, widget, NULL,
 					image_rect->x, image_rect->y, image_rect->width, image_rect->height);
 		}
 		cairo_surface_t *surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, 
@@ -324,8 +324,10 @@ gboolean _gx_knob_pointer_event(GtkWidget *widget, gdouble x, gdouble y, const g
 	get_image_dimensions (widget, pb, &image_rect, &fcount);
 	
 	g_object_unref(pb);
-	x += widget->allocation.x;
-	y += widget->allocation.y;
+	GtkAllocation allocation;
+	gtk_widget_get_allocation(widget, &allocation);
+	x += allocation.x;
+	y += allocation.y;
 	_gx_regler_get_positions(GX_REGLER(widget), &image_rect, &value_rect);
 	if (!drag) {
 		if (_gx_regler_check_display_popup(GX_REGLER(widget), &image_rect, &value_rect, event)) {
@@ -333,8 +335,10 @@ gboolean _gx_knob_pointer_event(GtkWidget *widget, gdouble x, gdouble y, const g
 		}
 	}
 	static double last_y = 2e20;
-		GtkAdjustment *adj = gtk_range_get_adjustment(GTK_RANGE(widget));
-	double radius =  min(image_rect.width, image_rect.height) / 2;
+	GtkAdjustment *adj = gtk_range_get_adjustment(GTK_RANGE(widget));
+	gdouble lower = gtk_adjustment_get_lower(adj);
+	gdouble upper = gtk_adjustment_get_upper(adj);
+	double radius =	 min(image_rect.width, image_rect.height) / 2;
 	double posx = radius - x + image_rect.x; // x axis right -> left
 	double posy = radius - y + image_rect.y; // y axis top -> bottom
 	double value;
@@ -351,7 +355,8 @@ gboolean _gx_knob_pointer_event(GtkWidget *widget, gdouble x, gdouble y, const g
 		double scal = (finemode ? scaling*0.1 : scaling);
 		value = (posy - last_y) * scal;
 		last_y = posy;
-		gtk_range_set_value(GTK_RANGE(widget), adj->value + value * (adj->upper - adj->lower));
+		gdouble adj_value = gtk_adjustment_get_value(adj);
+		gtk_range_set_value(GTK_RANGE(widget), adj_value + value * (upper - lower));
 		return TRUE;
 	}
 
@@ -380,7 +385,7 @@ gboolean _gx_knob_pointer_event(GtkWidget *widget, gdouble x, gdouble y, const g
 		priv->last_quadrant = 0;
 	}
 	angle = (angle - scale_zero) / (2 * (M_PI-scale_zero)); // normalize to 0..1
-	gtk_range_set_value(GTK_RANGE(widget), adj->lower + angle * (adj->upper - adj->lower));
+	gtk_range_set_value(GTK_RANGE(widget), lower + angle * (upper - lower));
 	return TRUE;
 }
 
