@@ -26,8 +26,6 @@
 #include "GxGradient.h"
 #include <gdk/gdkkeysyms.h>
 
-#define gtk_widget_get_requisition(w, r) (*r = (w)->requisition)
-
 #define P_(s) (s)   // FIXME -> gettext
 #define I_(s) (s)   // FIXME -> gettext
 
@@ -40,6 +38,12 @@ struct _GxReglerPrivate
 	GtkRequisition value_req;
 	gdouble last_step;
 	GtkAdjustment *adjustment;
+	gchar *var_id;
+	GtkLabel *label;
+	gboolean show_value:1;
+	GtkPositionType value_position:2;
+	gdouble value_xalign;
+	PangoLayout *value_layout;
 };
 
 enum {
@@ -64,7 +68,6 @@ static void gx_regler_class_init(GxReglerClass *klass);
 static void gx_regler_init(GxRegler *regler);
 static void gx_control_parameter_interface_init (GxControlParameterIface *iface);
 static void gx_regler_finalize(GObject*);
-static void gx_regler_size_allocate (GtkWidget *widget, GtkAllocation *allocation);
 static void gx_regler_style_set (GtkWidget *widget, GtkStyle  *previous_style);
 static void gx_regler_destroy(GtkObject *object);
 static void gx_regler_set_property(
@@ -98,8 +101,8 @@ gx_regler_cp_configure(GxControlParameter *self, gchar* group, gchar *name, gdou
 {
 	g_return_if_fail(GX_IS_REGLER(self));
 	GxRegler *regler = GX_REGLER(self);
-	if (regler->label) {
-		gtk_label_set_text(regler->label, name);
+	if (regler->priv->label) {
+		gtk_label_set_text(regler->priv->label, name);
 	}
 	GtkRange *range = GTK_RANGE(self);
 	gtk_range_set_range(range, lower, upper);
@@ -318,7 +321,6 @@ static void gx_regler_class_init(GxReglerClass *klass)
 	widget_class->style_set = gx_regler_style_set;
 	widget_class->button_release_event = gx_regler_button_release;
 	widget_class->scroll_event = gx_regler_scroll;
-	widget_class->size_allocate = gx_regler_size_allocate;
 
 	range_class->value_changed = gx_regler_value_changed;
 	range_class->change_value = gx_regler_change_value;
@@ -558,9 +560,9 @@ static void gx_regler_class_init(GxReglerClass *klass)
 static void gx_regler_destroy(GtkObject *object)
 {
 	GxRegler *regler = GX_REGLER(object);
-	if (regler->label) {
-		g_object_unref(regler->label);
-		regler->label = 0;
+	if (regler->priv->label) {
+		g_object_unref(regler->priv->label);
+		regler->priv->label = NULL;
 	}
 	gx_regler_change_adjustment(regler, NULL);
 	g_signal_handlers_disconnect_by_func(
@@ -571,30 +573,20 @@ static void gx_regler_destroy(GtkObject *object)
 static void gx_regler_finalize(GObject *object)
 {
 	GxRegler *regler = GX_REGLER(object);
-	g_free(regler->var_id);
-	if (regler->value_layout) {
-		g_object_unref(regler->value_layout);
+	g_free(regler->priv->var_id);
+	if (regler->priv->value_layout) {
+		g_object_unref(regler->priv->value_layout);
 	}
 	G_OBJECT_CLASS(gx_regler_parent_class)->finalize(object);
 }
 
-static void gx_regler_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
-{
-	widget->allocation = *allocation;
-	if (gtk_widget_get_realized(widget))
-		gdk_window_move_resize(GTK_RANGE(widget)->event_window,
-							   widget->allocation.x,
-							   widget->allocation.y,
-							   widget->allocation.width,
-							   widget->allocation.height);
-}
-
 static void step_back(GtkRange *range)
 {
 	gdouble newval;
 	gboolean handled;
 
-	newval = range->adjustment->value - range->adjustment->step_increment;
+	GtkAdjustment *adjustment = gtk_range_get_adjustment(range);
+	newval = gtk_adjustment_get_value(adjustment) - gtk_adjustment_get_step_increment(adjustment);
 	g_signal_emit_by_name(range, "change-value", GTK_SCROLL_STEP_BACKWARD, newval, &handled);
 }
 
@@ -603,7 +595,8 @@ static void step_forward(GtkRange *range)
 	gdouble newval;
 	gboolean handled;
 
-	newval = range->adjustment->value + range->adjustment->step_increment;
+	GtkAdjustment *adjustment = gtk_range_get_adjustment(range);
+	newval = gtk_adjustment_get_value(adjustment) + gtk_adjustment_get_step_increment(adjustment);
 	g_signal_emit_by_name(range, "change-value", GTK_SCROLL_STEP_FORWARD, newval, &handled);
 }
 
@@ -613,7 +606,8 @@ static void page_back(GtkRange *range)
 	gdouble newval;
 	gboolean handled;
 
-	newval = range->adjustment->value - range->adjustment->page_increment;
+	GtkAdjustment *adjustment = gtk_range_get_adjustment(range);
+	newval = gtk_adjustment_get_value(adjustment) - gtk_adjustment_get_page_increment(adjustment);
 	g_signal_emit_by_name(range, "change-value", GTK_SCROLL_PAGE_BACKWARD, newval, &handled);
 }
 
@@ -622,14 +616,16 @@ static void page_forward(GtkRange *range)
 	gdouble newval;
 	gboolean handled;
 
-	newval = range->adjustment->value + range->adjustment->page_increment;
+	GtkAdjustment *adjustment = gtk_range_get_adjustment(range);
+	newval = gtk_adjustment_get_value(adjustment) + gtk_adjustment_get_page_increment(adjustment);
 	g_signal_emit_by_name(range, "change-value", GTK_SCROLL_PAGE_FORWARD, newval, &handled);
 }
 
 static void scroll_begin(GtkRange *range)
 {
 	gboolean handled;
-	g_signal_emit_by_name(range, "change-value", GTK_SCROLL_START, range->adjustment->lower,
+	g_signal_emit_by_name(range, "change-value", GTK_SCROLL_START,
+	              gtk_adjustment_get_lower(gtk_range_get_adjustment(range)),
 	              &handled);
 }
 
@@ -638,25 +634,28 @@ static void scroll_end(GtkRange *range)
 	gdouble newval;
 	gboolean handled;
 
-	newval = range->adjustment->upper - range->adjustment->page_size;
+	GtkAdjustment *adjustment = gtk_range_get_adjustment(range);
+	newval = gtk_adjustment_get_upper(adjustment) - gtk_adjustment_get_page_size(adjustment);
 	g_signal_emit_by_name(range, "change-value", GTK_SCROLL_END, newval, &handled);
 }
 
 static gboolean should_invert(GtkRange *range)
 {
-	if (range->orientation == GTK_ORIENTATION_HORIZONTAL) {
+	gboolean inverted = gtk_range_get_inverted(range);
+	if (gtk_orientable_get_orientation(GTK_ORIENTABLE(range)) == GTK_ORIENTATION_HORIZONTAL) {
+		gboolean flippable = gtk_range_get_flippable(range);
 		return
-			(range->inverted && !range->flippable) ||
-			(range->inverted && range->flippable && gtk_widget_get_direction (GTK_WIDGET (range)) == GTK_TEXT_DIR_LTR) ||
-			(!range->inverted && range->flippable && gtk_widget_get_direction (GTK_WIDGET (range)) == GTK_TEXT_DIR_RTL);
+			(inverted && !flippable) ||
+			(inverted && flippable && gtk_widget_get_direction (GTK_WIDGET (range)) == GTK_TEXT_DIR_LTR) ||
+			(!inverted && flippable && gtk_widget_get_direction (GTK_WIDGET (range)) == GTK_TEXT_DIR_RTL);
 	} else {
-		return range->inverted;
+		return inverted;
 	}
 }
 
 static gboolean gx_regler_scroll(GtkRange *range, GtkScrollType scroll)
 {
-	gdouble old_value = range->adjustment->value;
+	gdouble old_value = gtk_adjustment_get_value(gtk_range_get_adjustment(range));
 
 	switch (scroll) {
     case GTK_SCROLL_STEP_DOWN:
@@ -721,7 +720,7 @@ static gboolean gx_regler_scroll(GtkRange *range, GtkScrollType scroll)
       break;
     }
 
-  return range->adjustment->value != old_value;
+    return gtk_adjustment_get_value(gtk_range_get_adjustment(range)) != old_value;
 }
 
 static void gx_regler_move_slider(GtkRange *range, GtkScrollType scroll)
@@ -732,7 +731,7 @@ static void gx_regler_move_slider(GtkRange *range, GtkScrollType scroll)
 	             NULL);
 	if (cursor_only) {
 		GtkWidget *toplevel = gtk_widget_get_toplevel(GTK_WIDGET(range));
-		if (range->orientation == GTK_ORIENTATION_HORIZONTAL) {
+		if (gtk_orientable_get_orientation(GTK_ORIENTABLE(range)) == GTK_ORIENTATION_HORIZONTAL) {
 			if (scroll == GTK_SCROLL_STEP_UP || scroll == GTK_SCROLL_STEP_DOWN) {
 				if (toplevel) {
 					gtk_widget_child_focus(toplevel,
@@ -760,11 +759,11 @@ static void gx_regler_move_slider(GtkRange *range, GtkScrollType scroll)
 static void ensure_digits(GxRegler *regler)
 {
 	GxReglerPrivate *priv = regler->priv;
-	GtkAdjustment *adj = GTK_RANGE(regler)->adjustment;
+	GtkAdjustment *adj = gtk_range_get_adjustment(GTK_RANGE(regler));
 	if (!adj) {
 		return;
 	}
-	gdouble v = adj->step_increment;
+	gdouble v = gtk_adjustment_get_step_increment(adj);
 	if (v == priv->last_step) {
 		return;
 	}
@@ -777,7 +776,7 @@ static void ensure_digits(GxRegler *regler)
 		v *= 10;
 		n++;
 	}
-	GTK_RANGE(regler)->round_digits = n;
+	gtk_range_set_round_digits(GTK_RANGE(regler), n);
 }
 
 static gboolean gx_regler_change_value(GtkRange *range, GtkScrollType scroll, gdouble value)
@@ -815,8 +814,8 @@ gboolean _approx_in_rectangle(gdouble x, gdouble y, GdkRectangle *rect)
 
 static void gx_regler_ensure_layout(GxRegler *regler)
 {
-	if (regler->show_value && !regler->value_layout) {
-		regler->value_layout = gtk_widget_create_pango_layout(GTK_WIDGET(regler), NULL);
+	if (regler->priv->show_value && !regler->priv->value_layout) {
+		regler->priv->value_layout = gtk_widget_create_pango_layout(GTK_WIDGET(regler), NULL);
 	}
 }
 
@@ -832,11 +831,12 @@ static const double scale_zero = 20 * (M_PI/180); // defines "dead zone" for kno
 gdouble _gx_regler_get_step_pos(GxRegler *regler, gint step)
 {
 	GtkAdjustment *adj = gtk_range_get_adjustment(GTK_RANGE(regler));
-	double df = adj->upper - adj->lower;
+	gdouble lower = gtk_adjustment_get_lower(adj);
+	double df = gtk_adjustment_get_upper(adj) - lower;
 	if (df == 0.0) {
 		return 0.0;
 	} else {
-		return (adj->value - adj->lower) * step / df;
+		return (gtk_adjustment_get_value(adj) - lower) * step / df;
 	}
 }
 
@@ -844,43 +844,45 @@ void _gx_regler_get_positions(GxRegler *regler, GdkRectangle *image_rect,
                               GdkRectangle *value_rect)
 {
 	GtkWidget *widget = GTK_WIDGET(regler);
-	gint x = widget->allocation.x;
-	gint y = widget->allocation.y;
+	GtkAllocation allocation;
+	gtk_widget_get_allocation(widget, &allocation);
+	gint x = allocation.x;
+	gint y = allocation.y;
 	gint width = image_rect->width;
 	gint height =  image_rect->height;
 	gboolean show_value;
 	gtk_widget_style_get(widget, "show-value", &show_value, NULL);
-	if (regler->show_value && show_value) {
+	if (regler->priv->show_value && show_value) {
 		GxReglerPrivate *priv = regler->priv;
 		gint text_width = priv->value_req.width;
 		gint text_height = priv->value_req.height;
 		gint text_x = 0, text_y = 0;
 		gint value_spacing;
 		gtk_widget_style_get(widget, "value-spacing", &value_spacing, NULL);
-		switch (regler->value_position) {
+		switch (priv->value_position) {
 		case GTK_POS_LEFT:
-			text_x = x + (widget->allocation.width - width - text_width - value_spacing) / 2;
-			text_y = y + (widget->allocation.height - text_height) / 2;
-			image_rect->x = x + (widget->allocation.width - width + text_width + value_spacing) / 2;
-			image_rect->y = y + (widget->allocation.height - height) / 2;
+			text_x = x + (allocation.width - width - text_width - value_spacing) / 2;
+			text_y = y + (allocation.height - text_height) / 2;
+			image_rect->x = x + (allocation.width - width + text_width + value_spacing) / 2;
+			image_rect->y = y + (allocation.height - height) / 2;
 			break;
 		case GTK_POS_RIGHT:
-			text_x = x + value_spacing + (widget->allocation.width + width - text_width - value_spacing) / 2;
-			text_y = y + (widget->allocation.height - text_height) / 2;
-			image_rect->x = x + (widget->allocation.width - width - text_width - value_spacing) / 2;
-			image_rect->y = y + (widget->allocation.height - height) / 2;
+			text_x = x + value_spacing + (allocation.width + width - text_width - value_spacing) / 2;
+			text_y = y + (allocation.height - text_height) / 2;
+			image_rect->x = x + (allocation.width - width - text_width - value_spacing) / 2;
+			image_rect->y = y + (allocation.height - height) / 2;
 			break;
 		case GTK_POS_TOP:
-			text_x = x + (widget->allocation.width - text_width) / 2;
-			text_y = y + (widget->allocation.height - height - text_height - value_spacing) / 2;
-			image_rect->x = x + (widget->allocation.width - width) / 2;
-			image_rect->y = y + (widget->allocation.height - height + text_height + value_spacing) / 2;
+			text_x = x + (allocation.width - text_width) / 2;
+			text_y = y + (allocation.height - height - text_height - value_spacing) / 2;
+			image_rect->x = x + (allocation.width - width) / 2;
+			image_rect->y = y + (allocation.height - height + text_height + value_spacing) / 2;
 			break;
 		case GTK_POS_BOTTOM:
-			text_x = x + (widget->allocation.width - text_width) / 2;
-			text_y = y + value_spacing + (widget->allocation.height + height - text_height - value_spacing) / 2;
-			image_rect->x = x + (widget->allocation.width - width) / 2;
-			image_rect->y = y + (widget->allocation.height - height - text_height - value_spacing) / 2;
+			text_x = x + (allocation.width - text_width) / 2;
+			text_y = y + value_spacing + (allocation.height + height - text_height - value_spacing) / 2;
+			image_rect->x = x + (allocation.width - width) / 2;
+			image_rect->y = y + (allocation.height - height - text_height - value_spacing) / 2;
 			break;
 		}
 		if (value_rect) {
@@ -890,8 +892,8 @@ void _gx_regler_get_positions(GxRegler *regler, GdkRectangle *image_rect,
 			value_rect->height = text_height;
 		}
 	} else {
-		image_rect->x = x + (widget->allocation.width - width) / 2;
-		image_rect->y = y + (widget->allocation.height - height) / 2;
+		image_rect->x = x + (allocation.width - width) / 2;
+		image_rect->y = y + (allocation.height - height) / 2;
 		if (value_rect) {
 			value_rect->x = value_rect->y = value_rect->width = value_rect->height = 0;
 		}
@@ -902,8 +904,10 @@ gboolean _gx_regler_check_display_popup(GxRegler *regler, GdkRectangle *image_re
 					GdkRectangle *value_rect, GdkEventButton *event)
 {
 	// check if value entry popup requested
-	gdouble x = event->x + GTK_WIDGET(regler)->allocation.x;
-	gdouble y = event->y + GTK_WIDGET(regler)->allocation.y;
+	GtkAllocation allocation;
+	gtk_widget_get_allocation(GTK_WIDGET(regler), &allocation);
+	gdouble x = event->x + allocation.x;
+	gdouble y = event->y + allocation.y;
 	GdkRectangle *rect = NULL;
 	if (image_rect && _approx_in_rectangle(x, y, image_rect)) {
 		if (event->button == 3) {
@@ -933,7 +937,7 @@ static gchar* _gx_regler_format_value(GxRegler *regler, gdouble value)
 	if (fmt) {
 		return fmt;
 	} else {
-		int rd = GTK_RANGE(regler)->round_digits;
+		int rd = gtk_range_get_round_digits(GTK_RANGE(regler));
 		if (rd < 0) {
 			rd = 0;
 		}
@@ -953,7 +957,7 @@ static void set_value_color(GtkWidget *wi, cairo_t *cr)
 	GxGradient *grad;
 	gtk_widget_style_get(wi, "value-color", &grad, NULL);
 	if (!grad) {
-		GdkColor *p2 = &wi->style->fg[GTK_STATE_NORMAL];
+		GdkColor *p2 = &gtk_widget_get_style(wi)->fg[GTK_STATE_NORMAL];
 		cairo_set_source_rgba(cr,cairo_clr(p2->red),
 			cairo_clr(p2->green), cairo_clr(p2->blue), 0.8);
 		return;
@@ -981,7 +985,7 @@ static void get_value_border(GtkWidget *widget, GtkBorder *value_border)
 
 void _gx_regler_simple_display_value(GxRegler *regler, GdkRectangle *rect)
 {
-	if (!regler->show_value) {
+	if (!regler->priv->show_value) {
 		return;
 	}
 	gboolean show_value;
@@ -990,22 +994,23 @@ void _gx_regler_simple_display_value(GxRegler *regler, GdkRectangle *rect)
 		return;
 	}
     GtkWidget *widget = GTK_WIDGET(regler);
-    PangoLayout *l = regler->value_layout;
+    GtkAdjustment* adjustment = gtk_range_get_adjustment(GTK_RANGE(regler));
+    PangoLayout *l = regler->priv->value_layout;
     PangoRectangle logical_rect;
 	gchar *txt;
 	ensure_digits(regler);
-	txt = _gx_regler_format_value(regler, GTK_RANGE(regler)->adjustment->value);
+	txt = _gx_regler_format_value(regler, gtk_adjustment_get_value(adjustment));
     pango_layout_set_text(l, txt, -1);
     g_free (txt);
     pango_layout_get_pixel_extents(l, NULL, &logical_rect);
-    gtk_paint_layout(widget->style, widget->window, gtk_widget_get_state(widget),
+    gtk_paint_layout(gtk_widget_get_style(widget), gtk_widget_get_window(widget), gtk_widget_get_state(widget),
                      FALSE, rect, widget, "label", rect->x+(rect->width - logical_rect.width)/2,
-                     rect->y, regler->value_layout);
+                     rect->y, regler->priv->value_layout);
 }
 
 void _gx_regler_display_value(GxRegler *regler, GdkRectangle *rect)
 {
-	if (!regler->show_value) {
+	if (!regler->priv->show_value) {
 		return;
 	}
 	gboolean show_value;
@@ -1014,7 +1019,7 @@ void _gx_regler_display_value(GxRegler *regler, GdkRectangle *rect)
 	if (!show_value) {
 		return;
 	}
-	cairo_t *cr = gdk_cairo_create(widget->window);
+	cairo_t *cr = gdk_cairo_create(gtk_widget_get_window(widget));
 	GtkBorder border;
 	get_value_border(widget, &border);
 	//gint inset = max(0, min(2, min(min(border.left-4, border.right-4), min(border.top-1, border.bottom-1))));
@@ -1033,14 +1038,14 @@ void _gx_regler_display_value(GxRegler *regler, GdkRectangle *rect)
 
 	gchar *txt;
 	ensure_digits(regler);
-	txt = _gx_regler_format_value(regler, GTK_RANGE(regler)->adjustment->value);
+	txt = _gx_regler_format_value(regler, gtk_adjustment_get_value(gtk_range_get_adjustment(GTK_RANGE(regler))));
 	set_value_color(GTK_WIDGET(regler),cr);
-    PangoLayout *l = regler->value_layout;
+    PangoLayout *l = regler->priv->value_layout;
     pango_layout_set_text(l, txt, -1);
     g_free(txt);
     PangoRectangle logical_rect;
     pango_layout_get_pixel_extents(l, NULL, &logical_rect);
-    gdouble off = border_width + border.left + regler->value_xalign *
+    gdouble off = border_width + border.left + regler->priv->value_xalign *
 		(rect->width - logical_rect.width - (2*border_width + border.left + border.right));
     cairo_move_to(cr, x0-1+off, y0+3);
     pango_cairo_show_layout(cr, l);
@@ -1050,7 +1055,7 @@ void _gx_regler_display_value(GxRegler *regler, GdkRectangle *rect)
 
 void _gx_regler_calc_size_request(GxRegler *regler, GtkRequisition *requisition)
 {
-	if (!regler->show_value) {
+	if (!regler->priv->show_value) {
 		return;
 	}
 	gboolean show_value;
@@ -1068,19 +1073,19 @@ void _gx_regler_calc_size_request(GxRegler *regler, GtkRequisition *requisition)
 	gchar *txt;
 	ensure_digits(regler);
 	txt = _gx_regler_format_value(regler, gtk_adjustment_get_lower(adj));
-	pango_layout_set_text(regler->value_layout, txt, -1);
+	pango_layout_set_text(regler->priv->value_layout, txt, -1);
 	g_free(txt);
-	pango_layout_get_pixel_extents(regler->value_layout, NULL, &logical_rect1);
+	pango_layout_get_pixel_extents(regler->priv->value_layout, NULL, &logical_rect1);
 	txt = _gx_regler_format_value(regler, gtk_adjustment_get_upper(adj));
-	pango_layout_set_text(regler->value_layout, txt, -1);
+	pango_layout_set_text(regler->priv->value_layout, txt, -1);
 	g_free(txt);
-	pango_layout_get_pixel_extents(regler->value_layout, NULL, &logical_rect2);
+	pango_layout_get_pixel_extents(regler->priv->value_layout, NULL, &logical_rect2);
 	gint height = max(logical_rect1.height,logical_rect2.height) + border.top + border.bottom;
 	gint width = max(logical_rect1.width,logical_rect2.width) + border.left + border.right;
 	GxReglerPrivate *priv = regler->priv;
 	priv->value_req.width = width;
 	priv->value_req.height = height;
-	switch (regler->value_position) {
+	switch (regler->priv->value_position) {
 	case GTK_POS_LEFT:
 	case GTK_POS_RIGHT:
 		requisition->width += width + value_spacing;
@@ -1107,15 +1112,19 @@ static void gx_regler_set_value (GtkWidget *widget, int dir_down)
 	g_assert(GX_IS_REGLER(widget));
 
 	GtkAdjustment *adj = gtk_range_get_adjustment(GTK_RANGE(widget));
+	gdouble adj_value = gtk_adjustment_get_value(adj);
+	gdouble lower = gtk_adjustment_get_lower(adj);
+	gdouble upper = gtk_adjustment_get_upper(adj);
+	gdouble step_increment = gtk_adjustment_get_step_increment(adj);
 
-	int oldstep = (int)(0.5f + (adj->value - adj->lower) / adj->step_increment);
+	int oldstep = (int)(0.5f + (adj_value - lower) / step_increment);
 	int step;
-	int nsteps = (int)(0.5f + (adj->upper - adj->lower) / adj->step_increment);
+	int nsteps = (int)(0.5f + (upper - lower) / step_increment);
 	if (dir_down)
 		step = oldstep - 1;
 	else
 		step = oldstep + 1;
-	float value = adj->lower + step * (double)(adj->upper - adj->lower) / nsteps;
+	gdouble value = lower + step * (upper - lower) / nsteps;
 	gtk_widget_grab_focus(widget);
 	gtk_range_set_value(GTK_RANGE(widget), value);
 }
@@ -1160,7 +1169,7 @@ static gboolean dialog_key_press_before(
 {
 	if (event->keyval == GDK_Escape) {
 		// spinbutton to current adjustment value
-		gtk_adjustment_value_changed(GTK_SPIN_BUTTON(widget)->adjustment);
+		gtk_adjustment_value_changed(gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(widget)));
 		gtk_widget_destroy(GTK_WIDGET(data));
 		return TRUE;
 	}
@@ -1192,7 +1201,7 @@ static gboolean map_check(
 	}
 	rc = gdk_keyboard_grab(window, TRUE, GDK_CURRENT_TIME);
 	if (rc != GDK_GRAB_SUCCESS) {
-		gdk_display_pointer_ungrab(gdk_drawable_get_display(window),
+		gdk_display_pointer_ungrab(gdk_window_get_display(window),
 		                           GDK_CURRENT_TIME);
 		gtk_widget_destroy(dialog);
 		return TRUE;
@@ -1232,14 +1241,17 @@ static gboolean gx_regler_value_entry(GxRegler *regler, GdkRectangle *rect, GdkE
 	ensure_digits(regler);
 	GtkAdjustment *src_adj = GTK_ADJUSTMENT(
 		gtk_adjustment_new(
-			dst_adj->value, dst_adj->lower, dst_adj->upper,
-			dst_adj->step_increment, dst_adj->page_increment, dst_adj->page_size));
-	int rd = GTK_RANGE(regler)->round_digits;
+			gtk_adjustment_get_value(dst_adj), gtk_adjustment_get_lower(dst_adj),
+			gtk_adjustment_get_upper(dst_adj),
+			gtk_adjustment_get_step_increment(dst_adj),
+			gtk_adjustment_get_page_increment(dst_adj),
+			gtk_adjustment_get_page_size(dst_adj)));
+	int rd = gtk_range_get_round_digits(GTK_RANGE(regler));
 	if (rd < 0) {
 		rd = 0;
 	}
 	GtkWidget *spinner = gtk_spin_button_new(
-		src_adj, src_adj->step_increment, rd);
+		src_adj, gtk_adjustment_get_step_increment(src_adj), rd);
 	g_signal_connect(spinner, "output", G_CALLBACK(gx_regler_spinner_output), regler);
 	g_signal_connect(spinner, "input", G_CALLBACK(gx_regler_spinner_input), regler);
 	g_signal_connect(src_adj, "value-changed", G_CALLBACK(gx_regler_relay_value), dst_adj);
@@ -1257,9 +1269,9 @@ static gboolean gx_regler_value_entry(GxRegler *regler, GdkRectangle *rect, GdkE
 	gtk_widget_show(spinner);
 	gtk_widget_realize(GTK_WIDGET(dialog));
 	GtkRequisition rq;
-	gtk_widget_get_requisition(dialog, &rq);
+	gtk_widget_get_requisition(GTK_WIDGET(dialog), &rq);
 	gint xorg, yorg;
-	gdk_window_get_origin(GTK_WIDGET(regler)->window, &xorg, &yorg);
+	gdk_window_get_origin(gtk_widget_get_window(GTK_WIDGET(regler)), &xorg, &yorg);
 	gtk_window_move(GTK_WINDOW(dialog), xorg+rect->x+(rect->width-rq.width)/2, yorg+rect->y+(rect->height-rq.height)/2);
 	gtk_widget_show(dialog);
 	return FALSE;
@@ -1330,16 +1342,16 @@ static void gx_regler_change_adjustment(GxRegler *regler, GtkAdjustment *adjustm
 static void gx_regler_adjustment_notified(GObject *gobject, GParamSpec *pspec)
 {
 	GxRegler *regler = GX_REGLER(gobject);
-	gx_regler_change_adjustment(regler, regler->parent.adjustment);
+	gx_regler_change_adjustment(regler, gtk_range_get_adjustment(&regler->parent));
 }
 
 static void gx_regler_init(GxRegler *regler)
 {
 	regler->priv = GX_REGLER_GET_PRIVATE (regler);
-	GTK_RANGE(regler)->round_digits = -1;
-	regler->value_position = GTK_POS_BOTTOM;
-	regler->show_value = TRUE;
-	regler->value_xalign = 0.5;
+	gtk_range_set_round_digits(GTK_RANGE(regler), -1);
+	regler->priv->value_position = GTK_POS_BOTTOM;
+	regler->priv->show_value = TRUE;
+	regler->priv->value_xalign = 0.5;
 	gtk_widget_set_can_focus(GTK_WIDGET(regler), TRUE);
 	gtk_widget_set_receives_default(GTK_WIDGET(regler), TRUE);
 	gtk_widget_set_has_window(GTK_WIDGET(regler), FALSE);
@@ -1352,8 +1364,8 @@ static void gx_regler_init(GxRegler *regler)
 
 static void gx_regler_set_var_id(GxRegler *regler, const gchar *str)
 {
-	g_free(regler->var_id);
-	regler->var_id = g_strdup(str ? str : "");
+	g_free(regler->priv->var_id);
+	regler->priv->var_id = g_strdup(str ? str : "");
 	g_object_notify(G_OBJECT(regler), "var-id");
 }
 
@@ -1375,7 +1387,7 @@ static void gx_regler_set_property (
 		gx_regler_set_value_position(regler, GtkPositionType(g_value_get_enum(value)));
 		break;
 	case PROP_VALUE_XALIGN:
-		regler->value_xalign = g_value_get_double(value);
+		regler->priv->value_xalign = g_value_get_double(value);
 		gtk_widget_queue_draw(GTK_WIDGET(object));
 		g_object_notify(object, "value-xalign");
 		break;
@@ -1397,22 +1409,22 @@ static void gx_regler_get_property(
 
 	switch(prop_id) {
 	case PROP_VAR_ID:
-		g_value_set_string (value, regler->var_id);
+		g_value_set_string (value, regler->priv->var_id);
 		break;
 	case PROP_SHOW_VALUE:
-		g_value_set_boolean(value, regler->show_value);
+		g_value_set_boolean(value, regler->priv->show_value);
 		break;
 	case PROP_VALUE_POSITION:
-		g_value_set_enum(value, regler->value_position);
+		g_value_set_enum(value, regler->priv->value_position);
 		break;
 	case PROP_VALUE_XALIGN:
-		g_value_set_double(value, regler->value_xalign);
+		g_value_set_double(value, regler->priv->value_xalign);
 		break;
 	case PROP_LABEL_REF:
-		g_value_set_object(value, regler->label);
+		g_value_set_object(value, regler->priv->label);
 		break;
 	case PROP_DIGITS:
-		g_value_set_int(value, GTK_RANGE(object)->round_digits);
+		g_value_set_int(value, gtk_range_get_round_digits(GTK_RANGE(object)));
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -1427,7 +1439,7 @@ static void gx_regler_get_property(
 void gx_regler_set_show_value(GxRegler *regler, gboolean value)
 {
 	g_return_if_fail(GX_IS_REGLER(regler));
-	regler->show_value = value;
+	regler->priv->show_value = value;
 	gtk_widget_queue_resize(GTK_WIDGET(regler));
 	g_object_notify(G_OBJECT(regler), "show-value");
 }
@@ -1435,13 +1447,13 @@ void gx_regler_set_show_value(GxRegler *regler, gboolean value)
 gboolean gx_regler_get_show_value(GxRegler *regler)
 {
 	g_return_val_if_fail(GX_IS_REGLER(regler), 0);
-	return regler->show_value;
+	return regler->priv->show_value;
 }
 
 void gx_regler_set_value_position(GxRegler *regler, GtkPositionType value)
 {
 	g_return_if_fail(GX_IS_REGLER(regler));
-	regler->value_position = value;
+	regler->priv->value_position = value;
 	gtk_widget_queue_resize(GTK_WIDGET(regler));
 	g_object_notify(G_OBJECT(regler), "value-position");
 }
@@ -1449,19 +1461,19 @@ void gx_regler_set_value_position(GxRegler *regler, GtkPositionType value)
 GtkPositionType gx_regler_get_value_position(GxRegler *regler)
 {
 	g_return_val_if_fail(GX_IS_REGLER(regler), GTK_POS_BOTTOM);
-	return regler->value_position;
+	return regler->priv->value_position;
 }
 
 void gx_regler_set_label_ref(GxRegler *regler, GtkLabel *label)
 {
 	g_return_if_fail(GX_IS_REGLER(regler));
-	if (regler->label) {
-		g_object_unref(regler->label);
-		regler->label = 0;
+	if (regler->priv->label) {
+		g_object_unref(regler->priv->label);
+		regler->priv->label = NULL;
 	}
 	if (label) {
 		g_return_if_fail(GTK_IS_LABEL(label));
-		regler->label = label;
+		regler->priv->label = label;
 		g_object_ref(label);
 	}
 	g_object_notify(G_OBJECT(regler), "label-ref");
@@ -1471,5 +1483,5 @@ void gx_regler_set_label_ref(GxRegler *regler, GtkLabel *label)
 GtkLabel *gx_regler_get_label_ref(GxRegler *regler)
 {
 	g_return_val_if_fail(GX_IS_REGLER(regler), 0);
-	return regler->label;
+	return regler->priv->label;
 }
