@@ -106,7 +106,7 @@ static gboolean gx_wheel_expose (GtkWidget *widget, GdkEventExpose *event)
 		_gx_regler_get_positions(regler, &image_rect, &value_rect);
 		GtkAdjustment *adj = gtk_range_get_adjustment(GTK_RANGE(widget));
 		int smoth_pointer = 0;
-		if (wheelstate > (adj->upper - adj->lower)) {
+		if (wheelstate > (gtk_adjustment_get_upper(adj) - gtk_adjustment_get_lower(adj))) {
 			smoth_pointer = -4;
 		}
 		gdk_cairo_set_source_pixbuf(cr, wb, image_rect.x, image_rect.y);
@@ -153,9 +153,11 @@ static gboolean wheel_set_from_pointer(GtkWidget *widget, gdouble x, gdouble y,
 	GxWheelPrivate *priv = wheel->priv;
 	gint fcount;
 	get_image_dimensions (widget, wb, &image_rect, &fcount); 
-	x += widget->allocation.x;
-	y += widget->allocation.y;
-	
+	GtkAllocation allocation;
+	gtk_widget_get_allocation(widget, &allocation);
+	x += allocation.x;
+	y += allocation.y;
+
 	_gx_regler_get_positions(GX_REGLER(widget), &image_rect, &value_rect);
 	if (!drag) {
 		GdkRectangle *rect = NULL;
@@ -180,11 +182,14 @@ static gboolean wheel_set_from_pointer(GtkWidget *widget, gdouble x, gdouble y,
 	}
 
 	double value;
+        gdouble lower = gtk_adjustment_get_lower(adj);
+        gdouble upper = gtk_adjustment_get_upper(adj);
+        gdouble adj_value = gtk_adjustment_get_value(adj);
 	if (!drag) {
 		priv->last_x = x;
 		if (event && event->type == GDK_2BUTTON_PRESS) {
 		    const int frame = 5;
-		    value = adj->lower + ((x - (image_rect.x+frame)) * (adj->upper - adj->lower)) / (image_rect.width-2*frame);
+		    value = lower + ((x - (image_rect.x+frame)) * (upper - lower)) / (image_rect.width-2*frame);
 		    gtk_range_set_value(GTK_RANGE(widget), value);
 		}
 		return TRUE;
@@ -192,9 +197,9 @@ static gboolean wheel_set_from_pointer(GtkWidget *widget, gdouble x, gdouble y,
 	int mode = ((state & GDK_CONTROL_MASK) == 0);
 	const double scaling = 0.01;
 	double scal = (mode ? scaling : scaling*0.1);
-	value = adj->value + (((x - priv->last_x) * scal) * (adj->upper - adj->lower));
+	value = adj_value + (((x - priv->last_x) * scal) * (upper - lower));
 	priv->last_x = x;
-	if (adj->value != value) 
+	if (adj_value != value)
 		gtk_range_set_value(GTK_RANGE(widget), value);
 	g_object_unref(wb);
 	return TRUE;
