@@ -70,6 +70,8 @@ static image_entry image_data[] = {
 	{ "resetbutton_off" },
     { "follow_on" },
 	{ "follow_off" },
+    { "overdub_on" },
+	{ "overdub_off" },
 	{ "vslider" },
 	{ "wheel_back" },
     { "wheel_vertical_back" },
@@ -83,6 +85,8 @@ static image_entry image_data[] = {
 	{ "guitarix" },
     { "screw" },
     { "logo" },
+    { "bypass_on" },
+	{ "bypass_off" },
 
     { "background1" },
     { "background2" },
