@@ -1427,6 +1427,148 @@ int PreampConvolver::register_pre(const ParamReg& reg) {
     return 0;
 }
 
+//// STEREO /////
+#include "faust/preamp_impulse_former_st.cc"
+
+static int pre_load_stereo_ui(const UiBuilder& builder, int format) {
+    if (format & UI_FORM_GLADE) {
+	builder.load_glade_file("ampimpulse_st_ui.glade");
+    return 0;
+    } else if (format & UI_FORM_STACK) {
+    builder.openHorizontalhideBox("");
+    builder.create_selector_no_caption("pre_st.select");
+    builder.closeBox();
+    builder.openVerticalBox("");
+    {
+	builder.openHorizontalBox("");
+	{
+	    builder.insertSpacer();
+	    builder.create_selector_no_caption("pre_st.select");
+	    builder.create_small_rackknobr("pre_st.bass", "Bass");
+	    builder.create_small_rackknobr("pre_st.treble", "Treble");
+	    builder.create_mid_rackknob("pre_st.Level", "Level");
+	}
+	builder.closeBox();
+    }
+    builder.closeBox();
+    return 0;
+    } else {
+    return -1;
+    }
+
+}
+
+PreampStereoConvolver::PreampStereoConvolver(EngineControl& engine, sigc::slot<void> sync,
+    gx_resample::BufferResampler& resamp):
+    FixedBaseConvolver(engine, sync, resamp),
+    current_pre(-1),
+    level(0),
+    preamp(0),
+    bass(0),
+    treble(0),
+    sum(no_sum),
+    pre_names(new value_pair[pre_table_size+1]),
+    impf(),
+    smp(),
+    smps() {
+    for (unsigned int i = 0; i < pre_table_size; ++i) {
+	PreEntry& pre = getPreEntry(i);
+	pre_names[i].value_id = pre.value_id;
+	pre_names[i].value_label = pre.value_label;
+    }
+    pre_names[pre_table_size].value_id = 0;
+    pre_names[pre_table_size].value_label = 0;
+    id = "pre_st";
+    name = N_("Amp Impulse");
+    category = N_("Tone Control");
+    load_ui = pre_load_stereo_ui;
+    stereo_audio = run_pre_conf;
+    register_params = register_pre;
+}
+
+PreampStereoConvolver::~PreampStereoConvolver() {
+    delete[] pre_names;
+}
+
+bool PreampStereoConvolver::do_update() {
+    bool configure = preamp_changed();
+    if (conv.is_runnable()) {
+	conv.set_not_runnable();
+	sync();
+	conv.stop_process();
+    }
+    PreDesc& pre = *getPreEntry(preamp).data;
+    if (current_pre == -1) {
+	unsigned int sr = getSamplingFreq();
+	unsigned int sru = 96000;
+	unsigned int fact = sru/sr;
+	
+	smp.setup(sr, fact*sr);
+	smps.setup(sr, fact*sr);
+	impf.init(pre.ir_sr);
+    }
+    float pre_irdata_c[pre.ir_count];
+    impf.clear_state_f();
+    impf.compute(pre.ir_count,pre.ir_data,pre_irdata_c);
+    while (!conv.checkstate());
+    if (configure) {
+	if (!conv.configure_stereo(pre.ir_count, pre_irdata_c, pre.ir_sr)) {
+	    return false;
+	}
+    } else {
+	if (!conv.update_stereo(pre.ir_count, pre_irdata_c, pre.ir_sr)) {
+	    return false;
+	}
+    }
+    update_preamp();
+    update_sum();
+    return conv_start();
+}
+
+bool PreampStereoConvolver::start(bool force) {
+    if (force) {
+	current_pre = -1;
+    }
+    if (preamp_changed() || sum_changed()) {
+	return do_update();
+    } else {
+	while (!conv.checkstate());
+	if (!conv.is_runnable()) {
+	    return conv_start();
+	}
+	return true;
+    }
+}
+
+void PreampStereoConvolver::check_update() {
+    if (preamp_changed() || sum_changed()) {
+	do_update();
+    } 
+}
+
+void PreampStereoConvolver::run_pre_conf(int count, float *input0, float *input1, float *output0, float *output1, PluginDef *p) {
+    PreampStereoConvolver& self = *static_cast<PreampStereoConvolver*>(p);
+	FAUSTFLOAT buf[self.smp.max_out_count(count)];
+	FAUSTFLOAT buf1[self.smps.max_out_count(count)];
+	int ReCount = self.smp.up(count, output0, buf);
+	self.smps.up(count, output1, buf1);
+    if (!self.conv.compute_stereo(ReCount,buf,buf1)) {
+	self.engine.overload(EngineControl::ov_Convolver, "pre_st");
+    }
+	self.smp.down(buf, output0);
+	self.smps.down(buf1, output1);
+}
+
+int PreampStereoConvolver::register_pre(const ParamReg& reg) {
+    PreampStereoConvolver& pre = *static_cast<PreampStereoConvolver*>(reg.plugin);
+    reg.registerIEnumVar("pre_st.select", "select", "B", "", pre.pre_names, &pre.preamp, 0);
+    reg.registerVar("pre_st.Level", N_("Level"),  "SA", N_("Level"), &pre.level,  1.0, 0.1, 2.1, 0.1);
+    reg.registerVar("pre_st.bass", N_("Bass"),   "SA", N_("Bass"), &pre.bass,   0.0, -10.0, 10.0, 0.5);
+    reg.registerVar("pre_st.treble", N_("Treble"), "SA", N_("Treble"), &pre.treble, 0.0, -10.0, 10.0, 0.5);
+    pre.impf.register_par(reg);
+    return 0;
+}
+
 /****************************************************************
  ** class ContrastConvolver
  */
@@ -1520,7 +1662,101 @@ void ContrastConvolver::run_contrast(int count, float *input0, float *output0, P
 }
 
 /****************************************************************
- ** class smbPitchShift
+ ** class Directout
+ */
+Plugin Directout::directoutput = Plugin();
+
+Directout::Directout(EngineControl& engine_, sigc::slot<void> sync_) 
+	: PluginDef(), 
+      outdata(0),
+	  engine(engine_),
+	  sync(sync_),
+	  mem_allocated(false),
+	  plugin() {
+    directoutput.set_pdef(this);
+	version = PLUGINDEF_VERSION;
+	flags = 0;
+	id = "dout";
+	name = N_("Directoutputr");
+	stereo_audio = compute_static;
+	set_samplerate = init_static;
+	activate_plugin = 0;
+	plugin = this;
+    engine.signal_buffersize_change().connect(
+    sigc::mem_fun(*this, &Directout::change_buffersize));
+}
+
+Directout::~Directout() {
+    mem_free();
+}
+
+inline void Directout::init(unsigned int samplingFreq)
+{
+	bsize = int(engine.get_buffersize());
+	fSamplingFreq = samplingFreq;
+	mem_alloc();
+}
+
+void Directout::init_static(unsigned int samplingFreq, PluginDef *p)
+{
+	static_cast<Directout*>(p)->init(samplingFreq);
+}
+
+void Directout::mem_alloc()
+{
+    if (mem_allocated) {
+        return;
+    }
+    bsize = int(engine.get_buffersize());
+    assert(bsize>0);
+    try {
+       outdata = new float[bsize]();
+    } catch(...) {
+            gx_print_error("Directout", "cant allocate memory pool");
+            return;
+        }
+    mem_allocated = true;
+}
+
+void Directout::mem_free()
+{
+    mem_allocated = false;
+    if (outdata) { delete outdata; outdata = 0; }
+}
+
+void Directout::change_buffersize(unsigned int size)
+{
+    sync();
+    if (mem_allocated) {
+        mem_free();
+        mem_alloc();
+    }
+}
+
+void always_inline Directout::compute(int count, float *input0, float *input1, float *output0, float *output1) {
+    if (!fdfill) {
+        return;
+    }
+    for (int i=0; i<count; i++) {
+        output0[i] =  input0[i] + outdata[i];
+        output1[i] =  input1[i] + outdata[i];
+    }
+    memset(outdata,0,count*sizeof(float));
+    fdfill = false;
+}
+
+void Directout::set_data(bool dfill) {
+    fdfill = dfill;
+}
+
+void __rt_func Directout::compute_static(int count, FAUSTFLOAT *input0, FAUSTFLOAT *input1, FAUSTFLOAT *output0, FAUSTFLOAT *output1, PluginDef *p)
+{
+	static_cast<Directout*>(p)->compute(count, input0, input1, output0, output1);
+}
+
+
+/****************************************************************
+ ** class LiveLooper
  */
 
 #include "gx_livelooper.cc"
@@ -1537,6 +1773,45 @@ void ContrastConvolver::run_contrast(int count, float *input0, float *output0, P
 
 #include "faust/drumseq.cc"
 
+
+float* Drumout::set = 0;
+float* Drumout::data = 0;
+bool Drumout::mb = false;
+Plugin Drumout::output_drum = Plugin();
+Plugin Drumout::input_drum = Plugin();
+PluginDef Drumout::outputdrum = PluginDef();
+
+Drumout::Drumout() {
+
+    output_drum.set_pdef(&outputdrum);
+
+    outputdrum.version = PLUGINDEF_VERSION;
+    outputdrum.id = "drumout";
+    outputdrum.name = "?drumout";
+    outputdrum.stereo_audio = outputdrum_compute;
+}
+
+void always_inline Drumout::outputdrum_compute(int count, float *input0, float *input1, float *output0, float *output1, PluginDef*) {
+    if (!(*set) || !input_drum.get_on_off() || !mb) {
+        return;
+    }
+    for (int i=0; i<count; i++) {
+        output0[i] =  input0[i] + data[i];
+        output1[i] =  input1[i] + data[i];
+    }
+    memset(data,0,count*sizeof(float));
+}
+
+void Drumout::set_data(float* mode, bool ready, float* buf) {
+    set = mode;
+    mb = ready;
+    data = buf;
+}
+
+void Drumout::set_plugin(Plugin p) {
+    input_drum = p;
+}
+
 static const char* seq_groups[] = {
 	"hat_closed.dsp", N_("DrumSequencer"),
 	"kick.dsp", N_("DrumSequencer"),
@@ -1546,7 +1821,7 @@ static const char* seq_groups[] = {
 	0
 };
 
-DrumSequencer::DrumSequencer(ParamMap& param_)
+DrumSequencer::DrumSequencer(ParamMap& param_, EngineControl& engine_, sigc::slot<void> sync_)
 	: PluginDef(), 
 	  Vectom(0),
 	  Vectom1(0),
@@ -1554,6 +1829,11 @@ DrumSequencer::DrumSequencer(ParamMap& param_)
 	  Veckick(0),
 	  Vecsnare(0),
 	  Vechat(0),
+	  engine(engine_),
+	  mem_allocated(false),
+	  sync(sync_),
+	  ready(false),
+	  outdata(0),
 	  param(param_),
 	  tomset(),
 	  tomp(0),
@@ -1583,13 +1863,17 @@ DrumSequencer::DrumSequencer(ParamMap& param_)
 	register_params = register_params_static;
 	delete_instance = del_instance;
 	plugin = this;
+    engine.signal_buffersize_change().connect(
+    sigc::mem_fun(*this, &DrumSequencer::change_buffersize));
 }
 
 DrumSequencer::~DrumSequencer() {
+    mem_free();
 }
 
 inline void DrumSequencer::init(unsigned int samplingFreq)
 {
+	bsize = int(engine.get_buffersize());
 	fSamplingFreq = samplingFreq;
 	counter = 0;
 	step = 0;
@@ -1600,7 +1884,9 @@ inline void DrumSequencer::init(unsigned int samplingFreq)
 	fSlow7 = 0.0;
 	fSlow18 = 150.0;
 	position = 0.0;
+	mem_alloc();
 	drums.init(samplingFreq);
+    Drumout::set_plugin(plugin);
 }
 
 void DrumSequencer::init_static(unsigned int samplingFreq, PluginDef *p)
@@ -1608,6 +1894,41 @@ void DrumSequencer::init_static(unsigned int samplingFreq, PluginDef *p)
 	static_cast<DrumSequencer*>(p)->init(samplingFreq);
 }
 
+void DrumSequencer::mem_alloc()
+{
+    if (mem_allocated) {
+        return;
+    }
+    bsize = int(engine.get_buffersize());
+    assert(bsize>0);
+    try {
+       outdata = new float[bsize]();
+    } catch(...) {
+            gx_print_error("DrumSequencer", "cant allocate memory pool");
+            return;
+        }
+    mem_allocated = true;
+    Drumout::set_data(&fSlow22, mem_allocated, outdata);
+}
+
+void DrumSequencer::mem_free()
+{
+    ready = false;
+    mem_allocated = false;
+    Drumout::set_data(0, mem_allocated, 0);
+    if (outdata) { delete outdata; outdata = 0; }
+}
+
+void DrumSequencer::change_buffersize(unsigned int size)
+{
+    sync();
+    ready = false;
+    if (mem_allocated) {
+        mem_free();
+        mem_alloc();
+    }
+}
+
 int DrumSequencer::min_seq_size(){
 	int i = min(min(min(Vectom.size(),Veckick.size()),min(Vechat.size(),Vecsnare.size())),min(Vectom1.size(),Vectom2.size()));
 	return i-1;
@@ -1643,6 +1964,12 @@ void DrumSequencer::reset_snare() {
 	seq_size = min_seq_size();
 }
 
+// hat = 1600Hz
+// kick = 50Hz
+// toms = 90 - 128 - 150Hz
+// snare = 523 - 7040Hz
+// todo: add compressor
+
 void always_inline DrumSequencer::compute(int count, FAUSTFLOAT *input0, FAUSTFLOAT *output0)
 {
 	double 	fSlow15 = (60.0/double(fsliderbpm*ftact))*fSamplingFreq;
@@ -1687,7 +2014,12 @@ void always_inline DrumSequencer::compute(int count, FAUSTFLOAT *input0, FAUSTFL
 		fSlow5 = 0.0;
 		fSlow7 = 0.0;
 	}
-	drums.compute(count,input0,output0);
+    if (int(fSlow22 && mem_allocated)) {
+        memcpy(output0, input0, count * sizeof(float));
+        drums.compute(count,outdata,outdata);
+    } else {
+        drums.compute(count,input0,output0);
+    }
 }
 
 void __rt_func DrumSequencer::compute_static(int count, FAUSTFLOAT *input0, FAUSTFLOAT *output0, PluginDef *p)
@@ -1721,6 +2053,7 @@ int DrumSequencer::register_par(const ParamReg& reg)
 	reg.registerVar("seq.set_sync","","BO",N_("Set stepper back on Beat "),0, 0.0, 0.0, 1.0, 1.0);
 	reg.registerVar("seq.reset_step","","BO",N_("Set stepper one Start"),0, 0.0, 0.0, 1.0, 1.0);
 	reg.registerVar("seq.follow","","BO",N_("follow playhead"),0, 0.0, 0.0, 1.0, 1.0);
+	reg.registerVar("seq.direct_out","","BA",N_("bypass the rack for direct output"),&fSlow22, 0.0, 0.0, 1.0, 1.0);
 	for (int i=0; i<24; i++) Vectom.push_back(0);
 	for (int i=0; i<24; i++) Vectom1.push_back(0);
 	for (int i=0; i<24; i++) Vectom2.push_back(0);
