@@ -446,6 +446,7 @@ CmdlineOptions::CmdlineOptions()
       jack_uuid(),
       jack_uuid2(),
       jack_noconnect(false),
+      jack_single(false),
       jack_servername(),
       load_file(shellvar("GUITARIX_LOAD_FILE")),
       style_dir(GX_STYLE_DIR),
@@ -464,6 +465,7 @@ CmdlineOptions::CmdlineOptions()
       rpcaddress(),
       onlygui(false),
       liveplaygui(false),
+      hideonquit(false),
       mute(false),
       setbank(),
       tuner_tet(),
@@ -551,6 +553,10 @@ CmdlineOptions::CmdlineOptions()
     opt_liveplaygui.set_short_name('L');
     opt_liveplaygui.set_long_name("liveplaygui");
     opt_liveplaygui.set_description("start with Live Play GUI");
+    Glib::OptionEntry opt_hideonquit;
+    opt_hideonquit.set_short_name('E');
+    opt_hideonquit.set_long_name("hideonquit");
+    opt_hideonquit.set_description("only hide GUI instead quit engine");
     Glib::OptionEntry opt_mute;
     opt_mute.set_short_name('M');
     opt_mute.set_long_name("mute");
@@ -576,6 +582,7 @@ CmdlineOptions::CmdlineOptions()
     main_group.add_entry(opt_rpchost, rpcaddress);
     main_group.add_entry(opt_onlygui, onlygui);
     main_group.add_entry(opt_liveplaygui, liveplaygui);
+    main_group.add_entry(opt_hideonquit, hideonquit);
     main_group.add_entry(opt_mute, mute);
     main_group.add_entry(opt_bank, setbank);
     main_group.add_entry(opt_tuner_tet, tuner_tet);
@@ -620,6 +627,10 @@ CmdlineOptions::CmdlineOptions()
     opt_jack_instance.set_long_name("name");
     opt_jack_instance.set_description("instance name (default gx_head)");
     opt_jack_instance.set_arg_description("NAME");
+    Glib::OptionEntry opt_jack_single;
+    opt_jack_single.set_short_name('D');
+    opt_jack_single.set_long_name("disable-multi-client");
+    opt_jack_single.set_description("run guitarix as single client");
     Glib::OptionEntry opt_jack_uuid;
     opt_jack_uuid.set_short_name('U');
     opt_jack_uuid.set_long_name("jack-uuid");
@@ -640,6 +651,7 @@ CmdlineOptions::CmdlineOptions()
     optgroup_jack.add_entry(opt_jack_midi, jack_midi);
     optgroup_jack.add_entry(opt_jack_noconnect, jack_noconnect);
     optgroup_jack.add_entry(opt_jack_instance, jack_instance);
+    optgroup_jack.add_entry(opt_jack_single, jack_single);
     optgroup_jack.add_entry(opt_jack_uuid, jack_uuid);
     optgroup_jack.add_entry(opt_jack_uuid2, jack_uuid2);
     optgroup_jack.add_entry(opt_jack_servername, jack_servername);
@@ -794,7 +806,7 @@ void CmdlineOptions::read_ui_vars() {
 	}
 	jp.next(JsonParser::end_object);
 	jp.close();
-    } catch (JsonException) {
+    } catch (JsonException&) {
 	gx_print_warning("main", "can't read/parse ui_rc");
     }
     i.close();
@@ -825,7 +837,7 @@ void CmdlineOptions::write_ui_vars() {
 	jw.write_kv("system.show_rack", system_show_rack);
 	jw.end_object(true);
 	jw.close();
-    } catch (JsonException) {
+    } catch (JsonException&) {
 	gx_print_warning("main", "can't write ui_rc");
     }
     o.close();
