@@ -169,7 +169,9 @@ void SEQWindow::init_connect() {
     builder->find_widget("gxswitch8", set_sync);
     builder->find_widget("gxswitch9", reset_step);
     builder->find_widget("label9:rack_label_inverse", preset_label);
-
+    builder->find_widget("gxvaluedisplay1", step_value);
+    builder->find_widget("label8:rack_label_inverse", step_label);
+    
     Pango::FontDescription font = preset_label->get_style()->get_font();
     font.set_size(10*Pango::SCALE);
     font.set_weight(Pango::WEIGHT_BOLD);
@@ -196,9 +198,11 @@ void SEQWindow::init_connect() {
     std::string id;
     seq_pos->get_property("var_id",id);
 
+    int ti_o = 60;
+    if (!machine.get_jack()) ti_o = 250;
     Glib::signal_timeout().connect(
       sigc::bind<Gxw::Regler*>(sigc::bind<const std::string>(
-      sigc::mem_fun(*this, &SEQWindow::get_sequencer_pos),id), seq_pos), 60);
+      sigc::mem_fun(*this, &SEQWindow::get_sequencer_pos),id), seq_pos), ti_o);
 
     seq_count->signal_value_changed().connect(
       sigc::bind(sigc::mem_fun(*this, &SEQWindow::on_sec_length_changed), true));
@@ -230,6 +234,11 @@ void SEQWindow::init_connect() {
 
     gtk_window->signal_key_press_event().connect(
       sigc::mem_fun(this, &SEQWindow::on_key_press_event));
+
+    if (!machine.get_jack()) {
+        step_value->hide();
+        step_label->hide();
+    }
 }
 
 void SEQWindow::init_sequences(gx_engine::SeqParameter *p, Gtk::HBox* _box) {
@@ -544,7 +553,7 @@ bool SEQWindow::get_sequencer_pos(Gxw::Regler * regler, const std::string id) {
                 if (value<99.0) return true;
             }
             machine.signal_parameter_value<float>(id)(value);
-            machine.signal_parameter_value<float>("seq.step")(machine.get_parameter_value<float>("seq.step"));
+            if (machine.get_jack()) machine.signal_parameter_value<float>("seq.step")(machine.get_parameter_value<float>("seq.step"));
             if (machine.get_parameter_value<float>("seq.follow"))
                 scroll_playhead(value);
         }
