@@ -85,6 +85,8 @@ public:
     StereoMute stereomute;
     TunerAdapter tuner;
     MidiAudioBuffer midiaudiobuffer;
+    Drumout drumout;
+    Directout directout;
     MaxLevel maxlevel;
     OscilloscopeAdapter oscilloscope;
     ConvolverMonoAdapter mono_convolver;
@@ -92,6 +94,7 @@ public:
     CabinetConvolver cabinet;
     CabinetStereoConvolver cabinet_st;
     PreampConvolver preamp;
+    PreampStereoConvolver preamp_st;
     ContrastConvolver contrast;
     LiveLooper loop;
     SCapture record;
