@@ -1,4 +1,5 @@
 #include <cmath>
+#include <algorithm>
 #include "gx_resampler.h"
 
 #define max(x, y) (((x) > (y)) ? (x) : (y))
@@ -10,6 +11,13 @@ template <int N> inline int faustpower(int x) {return faustpower<N/2>(x) * faust
 template <>      inline int faustpower<0>(int x)        {return 1;}
 template <>      inline int faustpower<1>(int x)        {return x;}
 
+
+template<class T> inline T mydsp_faustpower2_f(T x) {return (x * x);}
+template<class T> inline T mydsp_faustpower3_f(T x) {return ((x * x) * x);}
+template<class T> inline T mydsp_faustpower4_f(T x) {return (((x * x) * x) * x);}
+template<class T> inline T mydsp_faustpower5_f(T x) {return ((((x * x) * x) * x) * x);}
+template<class T> inline T mydsp_faustpower6_f(T x) {return (((((x * x) * x) * x) * x) * x);}
+
 #define FAUSTFLOAT float
 #ifndef N_
 #define N_(String) (String)
