@@ -234,7 +234,7 @@ public:
 
 class DragIcon {
 private:
-    enum { gradient_length = 40 };
+    enum { gradient_length = 60 };
     Gtk::Window *window;
     Glib::RefPtr<Gdk::Pixbuf> drag_icon_pixbuf;
 private:
@@ -558,6 +558,30 @@ struct GxActions {
     Glib::RefPtr<Gtk::Action> online_preset_bank;
 };
 
+
+
+class SelectMidiChannel: public Gtk::Window {
+private:
+    Gtk::Label  *description;
+    Gtk::ComboBox *channelcombo;
+    gx_engine::GxMachineBase& machine;
+    sigc::signal<void> close;
+    void on_ok_button();
+    void on_cancel_button();
+    bool on_delete_event(GdkEventAny* event);
+    bool on_key_press_event(GdkEventKey *event);
+    static SelectMidiChannel* create_from_builder(BaseObjectType* cobject, Glib::RefPtr<gx_gui::GxBuilder> bld, gx_engine::GxMachineBase& m) {
+	return new SelectMidiChannel(cobject, bld, m);
+    }
+    SelectMidiChannel(BaseObjectType* cobject, Glib::RefPtr<gx_gui::GxBuilder> bld, gx_engine::GxMachineBase& m);
+public:
+    ~SelectMidiChannel();
+    static SelectMidiChannel* create(gx_system::CmdlineOptions& opt, gx_engine::GxMachineBase& machine);
+    sigc::signal<void>& signal_close() { return close; }
+};
+
+
+
 class MainWindow: public sigc::trackable {
 private:
     gx_system::CmdlineOptions& options;
@@ -571,6 +595,7 @@ private:
     RackContainer monorackcontainer;
     RackContainer stereorackcontainer;
     int pre_act;
+    int pool_act;
     bool is_visible;
    // bool ui_sleep();
     DragIcon *drag_icon;
@@ -587,6 +612,7 @@ private:
     gx_gui::StackBoxBuilder boxbuilder;
     gx_portmap::PortMapWindow* portmap_window;
     gx_gui::SelectJackControlPgm *select_jack_control;
+    SelectMidiChannel *select_midi_channel;
     TextLoggingBox fLoggingWindow;
     GxUiRadioMenu amp_radio_menu;
     Glib::RefPtr<Gdk::Pixbuf> pixbuf_insert_on;
@@ -730,6 +756,8 @@ private:
     void on_select_jack_control();
     void on_load_ladspa();
     void delete_select_jack_control();
+    void on_select_midi_channel();
+    void delete_select_midi_channel();
     void on_log_activate();
     bool on_log_activated(GdkEventButton* ev);
     bool on_log_scrolled(GdkEventScroll* ev);
