@@ -102,7 +102,11 @@ private:
     }
     void create_spin_value(const std::string& id, const char *label) {
 	UiDisplayWithCaption<Gxw::ValueDisplay> *w = new UiDisplayWithCaption<Gxw::ValueDisplay>(machine, id);
-	w->set_rack_label(label);
+    if (next_flags & UI_LABEL_INVERSE) {
+        w->set_rack_label_inverse(label);
+    } else {
+        w->set_rack_label(label);
+    }
 	w->get_regler()->set_name("show_always");
 	addwidget(w);
     }
@@ -136,11 +140,11 @@ private:
     void addCheckButton(const std::string& id, const char* label = 0);
     void addNumEntry(const std::string& id, const char* label = 0);
     void addMToggleButton(const std::string& id, const char* label = 0);
-    void addSmallJConvFavButton(const char* label, gx_jconv::IRWindow *irw);
     void openSetLabelBox();
     void openSetMonoLabelBox();
-    void addJConvFavButton(const char* label, gx_jconv::IRWindow *irw);
+    void addSmallJConvFavButton(const char* label, gx_jconv::IRWindow *irw);
     void addJConvButton(const char* label, gx_jconv::IRWindow *irw);
+    void addSmallSeqButton(const char* label, gx_seq::SEQWindow *seqw);
     void addSeqButton(const char* label, gx_seq::SEQWindow *seqw);
     void set_next_flags(int flags);
 private:
