@@ -396,6 +396,7 @@ private:
     Glib::ustring jack_uuid;
     Glib::ustring jack_uuid2;
     bool jack_noconnect;
+    bool jack_single;
     Glib::ustring jack_servername;
     std::string load_file;
     std::string style_dir;
@@ -414,6 +415,7 @@ private:
     Glib::ustring rpcaddress;
     bool onlygui;
     bool liveplaygui;
+    bool hideonquit;
     bool mute;
     Glib::ustring setbank;
     Glib::ustring tuner_tet;
@@ -483,6 +485,7 @@ public:
     bool get_clear_rc() const { return clear; }
     bool get_nogui() const { return nogui; }
     bool get_liveplaygui() const { return liveplaygui; }
+    bool get_hideonquit() const { return hideonquit; }
     bool get_mute() const { return mute; }
     const Glib::ustring& get_setbank() { return setbank; }
     const Glib::ustring& get_tuner_tet() { return tuner_tet; }
@@ -499,6 +502,7 @@ public:
     const Glib::ustring& get_jack_input() const { return jack_input; }
     const Glib::ustring& get_jack_servername() const { return jack_servername; }
     bool get_jack_noconnect() const { return jack_noconnect; }
+    bool get_jack_single() const { return jack_single; }
     bool get_opt_save_on_exit() const { return a_save; }
     bool get_opt_autosave() const { return auto_save; }
     Glib::ustring get_jack_output(unsigned int n) const;
