@@ -21,7 +21,9 @@
 #ifndef SRC_HEADERS_MACHINE_H_
 #define SRC_HEADERS_MACHINE_H_
 
-#include <ext/stdio_filebuf.h>
+// #include <ext/stdio_filebuf.h>
+#include <boost/iostreams/device/file_descriptor.hpp>
+#include <boost/iostreams/stream.hpp>
 #include "jsonrpc_methods.h"
 #ifdef HAVE_AVAHI
 #include "avahi_register.h"
@@ -186,6 +188,7 @@ public:
     virtual void midi_set_current_control(int v) = 0;
     virtual void midi_modifyCurrent(Parameter& param, float lower, float upper, bool toggle, int toggle_behaviour) = 0;
     virtual int midi_param2controller(Parameter& param, const MidiController** p) = 0;
+    virtual void set_midi_channel(int s) = 0;
     // Convolver
     virtual void reload_impresp_list(const std::string& path) = 0;
     sigc::signal<void,const std::string&, std::vector<gx_system::FileName> >& signal_impresp_list() {
@@ -377,6 +380,7 @@ public:
     virtual void midi_set_current_control(int v);
     virtual void midi_modifyCurrent(Parameter& param, float lower, float upper, bool toggle, int toggle_behaviour);
     virtual int midi_param2controller(Parameter& param, const MidiController** p);
+    virtual void set_midi_channel(int s);
     // Convolver
     virtual void reload_impresp_list(const std::string& path);
     virtual void load_impresp_dirs(std::vector<gx_system::FileName>& dirs);
@@ -394,8 +398,10 @@ private:
     sigc::signal<void> selection_changed;
     sigc::signal<void> presetlist_changed;
     Glib::RefPtr<Gio::Socket> socket;
-    __gnu_cxx::stdio_filebuf<char> *writebuf;
-    ostream *os;
+    // __gnu_cxx::stdio_filebuf<char> *writebuf;
+    boost::iostreams::file_descriptor_sink *writebuf;
+    // ostream *os;
+    boost::iostreams::stream<boost::iostreams::file_descriptor_sink> *os;    
     gx_system::JsonWriter *jw;
     std::vector<gx_system::JsonStringParser*> notify_list;
     sigc::connection idle_conn;
@@ -565,6 +571,7 @@ public:
     virtual void midi_set_current_control(int v);
     virtual void midi_modifyCurrent(Parameter& param, float lower, float upper, bool toggle, int toggle_behaviour);
     virtual int midi_param2controller(Parameter& param, const MidiController** p);
+    virtual void set_midi_channel(int s);
     // Convolver
     virtual void reload_impresp_list(const std::string& path);
     virtual void load_impresp_dirs(std::vector<gx_system::FileName>& dirs);
