@@ -1,4 +1,6 @@
 from __future__ import division
+import matplotlib
+# matplotlib.use('Qt4Agg') # set when you prefer to use the Qt backend over the Tk one
 import sympy, math, shutil, sys, os, numpy, pylab, warnings, tempfile, logging, argparse
 from cStringIO import StringIO
 import dk_simulator, models, circ, mk_netlist, dk_lib, simu, signals, generate_code
@@ -506,6 +508,8 @@ class Circuit(object):
     def read_gschem(self, filename, defs=None):
         self._clear_all()
         v = dict(vars(models))
+        v["Transistors"] = circ.Transistors
+        v["Diodes"] = circ.Diodes
         v["Tubes"] = circ.Tubes
         v["math"] = math
         if defs:
@@ -518,6 +522,8 @@ class Circuit(object):
     def read_netlist(self, filename):
         self._clear_all()
         v = vars(models)
+        v["Transistors"] = circ.Transistors
+        v["Diodes"] = circ.Diodes
         v["Tubes"] = circ.Tubes
         v["math"] = math
         with open(filename) as f:
@@ -731,7 +737,7 @@ class Circuit(object):
         for e in self.S:
             if e[0] in el:
                 for i in el[e[0]]:
-                    jl = J[i].nonzero()[1].A1
+                    jl = numpy.ravel(J[i].nonzero()[1])
                     for j in jl:
                         v = models.VCCS(str(e) + "l%d%d" % (i, j))
                         S.append((v, idx(Nl[j], 1), idx(Nl[j], -1), idx(Nr[i], 1), idx(Nr[i], -1)))
@@ -769,18 +775,47 @@ class Circuit(object):
         if filename is not None:
             f.close()
 
-    def save_faust_code(self, symbolic=False, filename=None):
+    def get_faust_code(self, module_id=None, symbolic=False, filename=None, FS=None, pre_filter=None):
         self._ensure_filter(symbolic=symbolic)
-        b, a = self.sim_filter.get_z_coeffs(samplerate=self.FS)
+        b, a = self.sim_filter.get_z_coeffs(samplerate=FS)
         l = self.parser.get_pot_attr()
-        m_id = self._get_module_id()
-        dsp, ui = simu.generate_faust_module(m_id, b, a, l, self.sim_filter)
-        ##FIXME where to save ui code?
+        m_id = self._get_module_id(module_id)
+        plugindef = self.plugindef
+        if not plugindef:
+            plugindef = PluginDef(m_id)
+        dsp, ui = simu.generate_faust_module(plugindef, b, a, l, self.sim_filter, pre_filter, build_script=self.build_script)
+        return dsp, ui
+
+    def get_simple_faust_code(self, module_id=None, symbolic=False, filename=None, FS=None, pre_filter=None):
+        self._ensure_filter(symbolic=symbolic)
+        b, a = self.sim_filter.get_z_coeffs(samplerate=FS)
+        l = self.parser.get_pot_attr()
+        m_id = self._get_module_id(module_id)
+        plugindef = self.plugindef
+        if not plugindef:
+            plugindef = PluginDef(m_id)
+        dsp, ui = simu.generate_simple_faust_module(plugindef, b, a, l, self.sim_filter, pre_filter, build_script=self.build_script)
+        return dsp, ui
+
+    def save_faust_code(self, module_id=None, symbolic=False, filename=None, FS=None, pre_filter=None):
+        self._ensure_filter(symbolic=symbolic)
+        b, a = self.sim_filter.get_z_coeffs(samplerate=FS)
+        l = self.parser.get_pot_attr()
+        m_id = self._get_module_id(module_id)
+        plugindef = self.plugindef
+        if not plugindef:
+            plugindef = PluginDef(m_id)
+        dsp, ui = simu.generate_faust_module(plugindef, b, a, l, self.sim_filter, pre_filter, build_script=self.build_script)
         if filename is None:
             sys.stdout.write(dsp)
+            sys.stdout.write(ui)
         else:
-            with open(filename,"w") as f:
+            dspname = "{0}.dsp".format(filename)
+            uiname = "{0}_ui.cc".format(filename)
+            with open(dspname,"w") as f:
                 f.write(dsp)
+            with open(uiname,"w") as f:
+                f.write(ui)
 
     def create_faust_module(self, module_id=None, symbolic=False, FS=None, pre_filter=None):
         self._ensure_filter(symbolic=symbolic)
